@@ -3,6 +3,7 @@ from typing import Any, Dict, Optional
 from fastapi import Depends, HTTPException, status
 from fastapi.security import APIKeyCookie
 
+from fief.crypto.token import get_token_hash
 from fief.dependencies.main_managers import get_admin_session_token_manager
 from fief.managers import AdminSessionTokenManager
 from fief.models import AdminSessionToken
@@ -19,7 +20,8 @@ async def get_optional_admin_session_token(
 ) -> Optional[AdminSessionToken]:
     if token is None:
         return None
-    session_token = await manager.get_by_token(token)
+    token_hash = get_token_hash(token)
+    session_token = await manager.get_by_token(token_hash)
     return session_token
 
 
